package ram

func (client *RamClient) CreateGroup()         {}
func (client *RamClient) GetGroup()            {}
func (client *RamClient) UpdateGroup()         {}
func (client *RamClient) ListGroup()           {}
func (client *RamClient) DeleteGroup()         {}
func (client *RamClient) AddUserToGroup()      {}
func (client *RamClient) RemoveUserFromGroup() {}
func (client *RamClient) ListGroupsForUser()   {}
func (client *RamClient) ListUsersForGroup()   {}
